package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcSjlytj;
import org.apache.ibatis.annotations.Param;

/**
 * 数据来源统计Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcSjlytjMapper 
{
    /**
     * 查询数据来源统计
     * 
     * @param id 数据来源统计主键
     * @return 数据来源统计
     */
    public TcSjlytj selectTcSjlytjById(Long id);

    /**
     * 查询数据来源统计列表
     * 
     * @param tcSjlytj 数据来源统计
     * @return 数据来源统计集合
     */
    public List<TcSjlytj> selectTcSjlytjList(TcSjlytj tcSjlytj);

    /**
     * 新增数据来源统计
     * 
     * @param tcSjlytj 数据来源统计
     * @return 结果
     */
    public int insertTcSjlytj(TcSjlytj tcSjlytj);

    /**
     * 修改数据来源统计
     * 
     * @param tcSjlytj 数据来源统计
     * @return 结果
     */
    public int updateTcSjlytj(TcSjlytj tcSjlytj);

    /**
     * 删除数据来源统计
     * 
     * @param id 数据来源统计主键
     * @return 结果
     */
    public int deleteTcSjlytjById(Long id);

    /**
     * 批量删除数据来源统计
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcSjlytjByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
