package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcSjly;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcSjlytj;
import com.ruoyi.tcZz.service.ITcSjlytjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 数据来源统计Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "数据来源统计")
@RequestMapping("/tcZz/networkSecurity/DataSourceTj")
public class TcSjlytjController extends BaseController {
    @Autowired
    private ITcSjlytjService tcSjlytjService;

    /**
     * 查询数据来源统计列表
     */
    @ApiOperation(value = "查询数据来源统计列表", response = TcSjlytj.class)
    @GetMapping("/list")
    public TableDataInfo list(TcSjlytj tcSjlytj) {
        startPage();
        List<TcSjlytj> list = tcSjlytjService.selectTcSjlytjList(tcSjlytj);
        return getDataTable(list);
    }

    /**
     * 导出数据来源统计列表
     */
    @ApiOperation("导出数据来源统计列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSjlytj tcSjlytj) {
        List<TcSjlytj> list = tcSjlytjService.selectTcSjlytjList(tcSjlytj);
        ExcelUtil<TcSjlytj> util = new ExcelUtil<TcSjlytj>(TcSjlytj.class);
        util.exportExcel(response, list, "数据来源统计数据");
    }

    /**
     * 获取数据来源统计详细信息
     */
    @ApiOperation("获取数据来源统计详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcSjlytjService.selectTcSjlytjById(id));
    }

    /**
     * 新增数据来源统计
     */
    @ApiOperation("新增数据来源统计")
    @PostMapping
    public AjaxResult add(@RequestBody TcSjlytj tcSjlytj) {
        return toAjax(tcSjlytjService.insertTcSjlytj(tcSjlytj));
    }

    /**
     * 修改数据来源统计
     */
    @ApiOperation("修改数据来源统计")
    @PutMapping
    public AjaxResult edit(@RequestBody TcSjlytj tcSjlytj) {
        return toAjax(tcSjlytjService.updateTcSjlytj(tcSjlytj));
    }

    /**
     * 删除数据来源统计
     */
    @ApiOperation("删除数据来源统计")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcSjlytjService.deleteTcSjlytjByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcSjlytj> util = new ExcelUtil<TcSjlytj>(TcSjlytj.class);
        List<TcSjlytj> tcSjlytjList = util.importExcel(file.getInputStream());
        tcSjlytjService.importUser(tcSjlytjList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcSjlytjService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcSjlytj> util = new ExcelUtil<TcSjlytj>(TcSjlytj.class);
        util.importTemplateExcel(response, " 数据来源统计");
    }
}
